// 解析文本带表情
const emojiMap = { // 根据[呲牙]可匹配的路径地址
	'[微笑]': 'emoji_0.png',
	'[呲牙]': 'emoji_1.png',
	'[下雨]': 'emoji_2.png'
}
const emojiUrl = 'http://xxxxxxxx/emoji/' // 为<img src="https://main.qcloudimg.com/raw/6be88c30a4552b5eb93d8eec243b6593.png"  style="margin:0;">图片的地址
function parseText(payload) {
	let renderDom = []
	// 文本消息
	let temp = payload.text
	let left = -1
	let right = -1
	while (temp !== '') {
		left = temp.indexOf('[')
		right = temp.indexOf(']')
		switch (left) {
			case 0:
				if (right === -1) {
					renderDom.push({
						name: 'text',
						text: temp
					})
					temp = ''
				} else {
					let _emoji = temp.slice(0, right + 1)
					if (emojiMap[_emoji]) { // 如果您需要渲染表情包，需要进行匹配您对应[呲牙]的表情包地址
						renderDom.push({
							name: 'img',
							src: emojiUrl + emojiMap[_emoji]
						})
						temp = temp.substring(right + 1)
					} else {
						renderDom.push({
							name: 'text',
							text: '['
						})
						temp = temp.slice(1)
					}
				}
				break
			case -1:
				renderDom.push({
					name: 'text',
					text: temp
				})
				temp = ''
				break
			default:
				renderDom.push({
					name: 'text',
					text: temp.slice(0, left)
				})
				temp = temp.substring(left)
				break
		}
	}
	return renderDom
}
// 最后的 renderDom 结构为[{name: 'text', text: 'XXX'}, {name: 'img', src: 'http://xxx'}......]
// 渲染当前数组即可得到想要的 UI 结果，如：XXX<img src="https://main.qcloudimg.com/raw/6be88c30a4552b5eb93d8eec243b6593.png"  style="margin:0;">XXX
// <img src="https://main.qcloudimg.com/raw/6be88c30a4552b5eb93d8eec243b6593.png"  style="margin:0;">XXX[呲牙XXX]

// 解析系统消息
function parseGroupSystemNotice(payload) {
	const groupName =
		payload.groupProfile.groupName || payload.groupProfile.groupID
	switch (payload.operationType) {
		case 1:
			return `${payload.operatorID} 申请加入群组：${groupName}`
		case 2:
			return `成功加入群组：${groupName}`
		case 3:
			return `申请加入群组：${groupName}被拒绝`
		case 4:
			return `被管理员${payload.operatorID}踢出群组：${groupName}`
		case 5:
			return `群：${groupName} 已被${payload.operatorID}解散`
		case 6:
			return `${payload.operatorID}创建群：${groupName}`
		case 7:
			return `${payload.operatorID}邀请你加群：${groupName}`
		case 8:
			return `你退出群组：${groupName}`
		case 9:
			return `你被${payload.operatorID}设置为群：${groupName}的管理员`
		case 10:
			return `你被${payload.operatorID}撤销群：${groupName}的管理员身份`
		case 255:
			return '自定义群系统通知'
	}
}


// 解析群提示消息
function parseGroupTipContent(payload) {
	switch (payload.operationType) {
		case this.TIM.TYPES.GRP_TIP_MBR_JOIN:
			return `群成员：${payload.userIDList.join(',')}，加入群组`
		case this.TIM.TYPES.GRP_TIP_MBR_QUIT:
			return `群成员：${payload.userIDList.join(',')}，退出群组`
		case this.TIM.TYPES.GRP_TIP_MBR_KICKED_OUT:
			return `群成员：${payload.userIDList.join(',')}，被${payload.operatorID}踢出群组`
		case this.TIM.TYPES.GRP_TIP_MBR_SET_ADMIN:
			return `群成员：${payload.userIDList.join(',')}，成为管理员`
		case this.TIM.TYPES.GRP_TIP_MBR_CANCELED_ADMIN:
			return `群成员：${payload.userIDList.join(',')}，被撤销管理员`
		default:
			return '[群提示消息]'
	}
}
